# Oriole-Service (企业级服务框架)

Rapidly create services. (构建企业级服务平台，以其微妙而能驰骋天下。)

[![build](https://travis-ci.org/zhouxiaoxiang/oriole-service.png?branch=master)](https://travis-ci.org/zhouxiaoxiang/oriole-service)

**[Framework]**

[Orile-Service](https://github.com/zhouxiaoxiang/oriole-service)

- Create a service. (创建服务)

```
  oriole go <name>

  e.g. oriole go log
```

- Run a service. (运行服务)

```
  oriole run <service>

  e.g. oriole run log
```

- Run unit tests. (执行测试)

```
  oriole test
```

- Create documents. (创建文档)

```
  oriole doc
```
